@@ -1,8 +1,8 @@
 #!/usr/bin/python
 #
-import json
-import os
+
 import sqlite3
+import urllib
 from datetime import datetime
 
 import requests
@@ -10,6 +10,11 @@ from tornado import web, ioloop, httpserver
 
 from .configuration import PlotmanConfig, get_db_path
 
+try:
+    import simplejson as json
+except ImportError:
+    import json
+
 
 def PostDat(dp: dict, cfg: PlotmanConfig):
     # sending post request and saving response as response object
@@ -38,17 +43,19 @@ if __name__ == "__main__":
 
 
 class MainHandler(web.RequestHandler):
-    def prepare(self):
-        if self.request.headers.get("Content-Type", "").startswith("application/json"):
-            self.json_args = json.loads(self.request.body)
-        else:
-            self.json_args = None
+    def initialize(self, *args, **kwargs):
+        self.remote_ip = self.request.headers.get('X-Forwarded-For', self.request.headers.get('X-Real-Ip', self.request.remote_ip))
+        self.using_ssl = (self.request.headers.get('X-Scheme', 'http') == 'https')
 
     def post(self):
         self.set_header("Content-Type", "text/plain")
-        req_body = self.json_args
+        req_body = self.request.body
+        jsondata = dict()
+        try:
+            jsondata = json.loads(req_body)
+        except:
+            jsondata = json.loads(urllib.unquote_plus(req_body))
 
-        remote_addr = os.environ.get('REMOTE_ADDR', '-')
         ts = datetime.now().strftime('%m-%d %H:%M:%S')
 
         con = sqlite3.connect(get_db_path())
@@ -60,10 +67,14 @@ class MainHandler(web.RequestHandler):
                            ip text NOT NULL
                    );''')
 
-        # Insert a row of data
-        cur.execute(f"INSERT INTO systemchia VALUES ('{ts}','{req_body}','{remote_addr}')")
+        if req_body is not None:
+            # Insert a row of data
+            cur.execute(f"INSERT INTO systemchia VALUES ('{ts}','{req_body}','{self.remote_ip}')")
+
         con.commit()
         con.close()
+
+        print(jsondata)
         print(req_body)
 
 
