@@ -13,17 +13,17 @@ from . import plot_util
 from .reporting import abbr_path, phase_str
 
 
-def job_phases_for_tmpdir(d, all_jobs):
+def job_phases_for_tmpdir(d, all_jobs) -> list:
     '''Return phase 2-tuples for jobs running on tmpdir d'''
     return sorted([j.progress() for j in all_jobs if j.tmpdir == d])
 
 
-def job_phases_for_dstdir(d, all_jobs):
+def job_phases_for_dstdir(d, all_jobs) -> list:
     '''Return phase 2-tuples for jobs outputting to dstdir d'''
     return sorted([j.progress() for j in all_jobs if j.dstdir == d])
 
 
-def is_plotting_cmdline(cmdline):
+def is_plotting_cmdline(cmdline) -> bool:
     return (
             len(cmdline) >= 4
             and 'python' in cmdline[0]
@@ -32,14 +32,6 @@ def is_plotting_cmdline(cmdline):
             and 'create' == cmdline[3]
     )
 
-
-def is_plot_moving(cmdline):
-    return (
-            len(cmdline) > 3
-            and cmdline[0].endswith('plmo')
-    )
-
-
 # This is a cmdline argument fix for https://github.com/ericaltendorf/plotman/issues/41
 def cmdline_argfix(cmdline):
     known_keys = 'krbut2dnea'
@@ -88,10 +80,14 @@ class Job:
     last_updated_time_in_min = 0
 
     @staticmethod
-    def get_running_jobs(logroot, cached_jobs=()) -> list:
-        '''Return a list of running plot jobs.  If a cache of preexisting jobs is provided,
-           reuse those previous jobs without updating their information.  Always look for
-           new jobs not already in the cache.'''
+    def genTasks(logroot, cached_jobs=()) -> list:
+        """
+        Return a list of running plot jobs.  If a cache of preexisting jobs is provided,
+        reuse those previous jobs without updating their information.  Always look for
+        new jobs not already in the cache. If the job status is already finish or the storage
+        is Zero then we need to make new
+        job scanning
+        """
         jobs = []
         cached_jobs_by_pid = {j.proc.pid: j for j in cached_jobs}
 
@@ -101,30 +97,28 @@ class Job:
             with contextlib.suppress(psutil.NoSuchProcess, psutil.AccessDenied):
                 if is_plotting_cmdline(proc.cmdline()):
                     if proc.pid in cached_jobs_by_pid.keys():
-                        jobs.append(cached_jobs_by_pid[proc.pid])  # Copy from cache
+                        cached_job = cached_jobs_by_pid[proc.pid]
+                        if cached_job.get_tmp_usage() == 0:
+                            try:
+                                job1 = Job(proc, logroot)
+                                if not job1.help:
+                                    jobs.append(job1)
+                            except Exception as e:
+                                jobs.append(cached_job)
+                        else:
+                            jobs.append(cached_job)
                     else:
                         try:
-                            job = Job(proc, logroot)
-                            if not job.help:
-                                jobs.append(job)
+                            job2 = Job(proc, logroot)
+                            if not job2.help:
+                                jobs.append(job2)
                         except Exception as e:
                             print("Error:", e)
                             pass
 
         return jobs
 
-    @staticmethod
-    def get_running_moving_jobs() -> list:
-        jobs = []
 
-        for proc in psutil.process_iter(['pid', 'cmdline']):
-            # Ignore processes which most likely have terminated between the time of iteration and data access.
-            with contextlib.suppress(psutil.NoSuchProcess, psutil.AccessDenied):
-                if is_plot_moving(proc.cmdline()):
-                    job = " ".join(proc.cmdline())
-                    jobs.append(job)
-
-        return jobs
 
     def __init__(self, proc, logroot):
         '''Initialize from an existing psutil.Process object.  must know logroot in order to understand open files'''
@@ -220,6 +214,7 @@ class Job:
         # (and being slow about it).  In this case, use the last metadata change as the start time.
         # TODO: we never come back to this; e.g. plot_id may remain uninitialized.
         # TODO: should we just use the process start time instead?
+
         if not found_log:
             self.start_time = datetime.fromtimestamp(os.path.getctime(self.logfile))
 
@@ -281,7 +276,7 @@ class Job:
         else:
             self.phase = (0, 0)
 
-    def check_freeze(self):
+    def check_freeze(self) -> None:
         assert self.logfile
         updatedAt = os.path.getmtime(self.logfile)
         now = datetime.now().timestamp()
@@ -291,11 +286,12 @@ class Job:
         '''Return a 2-tuple with the job phase and subphase (by reading the logfile)'''
         return self.phase
 
-    def plot_id_prefix(self):
+    @property
+    def plot_id_prefix(self) -> str:
         return self.plot_id[:8]
 
     # TODO: make this more useful and complete, and/or make it configurable
-    def status_str_long(self):
+    def status_str_long(self) -> str:
         return '{plot_id}\nk={k} r={r} b={b} u={u}\npid:{pid}\ntmp:{tmp}\ntmp2:{tmp2}\ndst:{dst}\nlogfile:{logfile}'.format(
             plot_id=self.plot_id,
             k=self.k,
@@ -313,7 +309,7 @@ class Job:
     def get_mem_usage(self):
         return self.proc.memory_info().vms  # Total, inc swapped
 
-    def get_tmp_usage(self):
+    def get_tmp_usage(self) -> int:
         total_bytes = 0
         with os.scandir(self.tmpdir) as it:
             for entry in it:
@@ -325,7 +321,7 @@ class Job:
                         pass
         return total_bytes
 
-    def get_run_status(self):
+    def get_run_status(self) -> str:
         '''Running, suspended, etc.'''
         status = self.proc.status()
         if status == psutil.STATUS_RUNNING:
@@ -339,21 +335,21 @@ class Job:
         else:
             return self.proc.status()
 
-    def get_time_wall(self):
+    def get_time_wall(self) -> int:
         create_time = datetime.fromtimestamp(self.proc.create_time())
         return int((datetime.now() - create_time).total_seconds())
 
-    def get_time_user(self):
+    def get_time_user(self) -> int:
         return int(self.proc.cpu_times().user)
 
-    def get_time_sys(self):
+    def get_time_sys(self) -> int:
         return int(self.proc.cpu_times().system)
 
-    def get_time_iowait(self):
+    def get_time_iowait(self) -> int:
         cpu_times = self.proc.cpu_times()
         iowait = getattr(cpu_times, 'iowait', None)
         if iowait is None:
-            return None
+            return 0
 
         return int(iowait)
 
@@ -402,7 +398,7 @@ def report_jdata(jobs, tmp_prefix='', dst_prefix='') -> list:
     for i, j in enumerate(sorted(jobs, key=job.Job.get_time_wall)):
         with j.proc.oneshot():
             dictionary = {
-                'plotid': j.plot_id[:8],
+                'plotid': j.plot_id_prefix,
                 'k': j.k,
                 'tmp': abbr_path(j.tmpdir, tmp_prefix),
                 'dst': abbr_path(j.dstdir, dst_prefix),
